@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1999 Erez Zadok
+ * Copyright (c) 1997-2000 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: opts.c,v 1.2 1998/12/27 06:24:48 ezk Exp $
+ * $Id: opts.c,v 1.8.2.1 2000/06/21 04:01:59 ezk Exp $
  *
  */
 
@@ -95,6 +95,7 @@ struct functable {
  */
 static int f_in_network(char *);
 static int f_netgrp(char *);
+static int f_netgrpd(char *);
 static int f_exists(char *);
 static int f_false(char *);
 static int f_true(char *);
@@ -102,7 +103,6 @@ static int f_true(char *);
 /*
  * STATICS:
  */
-static struct am_opts fs_static; /* copy of the options to play with */
 static char NullStr[] = "<NULL>";
 static char nullstr[] = "";
 static char *opt_dkey = NullStr;
@@ -112,7 +112,16 @@ static char *opt_key = nullstr;
 static char *opt_keyd = nullstr;
 static char *opt_map = nullstr;
 static char *opt_path = nullstr;
+static char uid_str[12], gid_str[12];
+char *opt_uid = uid_str;
+char *opt_gid = gid_str;
 static char *vars[8];
+static char *literal_dollar = "$"; /* ${dollar}: a literal '$' in maps */
+
+/*
+ * GLOBALS
+ */
+struct am_opts fs_static;	/* copy of the options to play with */
 
 
 /*
@@ -121,7 +130,7 @@ static char *vars[8];
  */
 static struct opt opt_fields[] = {
   /* Name and length.
-	Option str.		Selector str.	boolean fxn.	flags */
+	Option str.		Selector str.	boolean fxn.	case sensitive */
   { S("opts"),
        &fs_static.opt_opts,	0,		0, 		FALSE	},
   { S("host"),
@@ -174,6 +183,10 @@ static struct opt opt_fields[] = {
 	0,			&gopt.op_sys,	0,		TRUE	},
   { S("osver"),
 	0,			&gopt.op_sys_ver,	0,	TRUE	},
+  { S("full_os"),
+	0,			&gopt.op_sys_full,	0,	TRUE	},
+  { S("vendor"),
+	0,			&gopt.op_sys_vendor,	0,	TRUE	},
   { S("remopts"),
 	&fs_static.opt_remopts,	0,		0,		FALSE	},
   { S("mount"),
@@ -195,7 +208,13 @@ static struct opt opt_fields[] = {
   { S("cachedir"),
 	&fs_static.opt_cachedir, 0,		0,		FALSE	},
   { S("addopts"),
-       &fs_static.opt_addopts,	0,		0, 		FALSE	},
+	&fs_static.opt_addopts,	0,		0, 		FALSE	},
+  { S("uid"),
+	0,			&opt_uid,	0,		FALSE	},
+  { S("gid"),
+	0,			&opt_gid,	0, 		FALSE	},
+  { S("dollar"),
+	&literal_dollar,	0,		0,		FALSE	},
   { S("var0"),
 	&vars[0],		0,		0,		FALSE	},
   { S("var1"),
@@ -218,6 +237,7 @@ static struct opt opt_fields[] = {
 static struct functable functable[] = {
   { "in_network",	f_in_network },
   { "netgrp",		f_netgrp },
+  { "netgrpd",		f_netgrpd },
   { "exists",		f_exists },
   { "false",		f_false },
   { "true",		f_true },
@@ -494,7 +514,7 @@ eval_opts(char *opts, char *mapkey)
 	continue;
       } else if (NSTREQ(f, "!", 1) && (func = functable_lookup(&f[1]))) {
 	/* then this is a negated prefixed function such as "!exists" */
-	plog(XLOG_USER, "executing negated function %s", &f[1]);
+	plog(XLOG_INFO, "executing negated function %s", &f[1]);
 	if ((*func) (arg)) {
 	  return (0);
 	}
@@ -730,7 +750,7 @@ f_in_network(char *arg)
 }
 
 
-/* test if this host is in netgroup (arg) */
+/* test if this host (short hostname form) is in netgroup (arg) */
 static int
 f_netgrp(char *arg)
 {
@@ -744,6 +764,20 @@ f_netgrp(char *arg)
 }
 
 
+/* test if this host (fully-qualified name) is in netgroup (arg) */
+static int
+f_netgrpd(char *arg)
+{
+  int status;
+
+  status = innetgr(arg, opt_hostd, NULL, NULL);
+#ifdef DEBUG
+  plog(XLOG_USER, "netgrp = %s status = %d hostd = %s", arg, status, opt_hostd);
+#endif /* DEBUG */
+  return status;
+}
+
+
 /* test if file (arg) exists via lstat */
 static int
 f_exists(char *arg)
