@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: mount_linux.c,v 1.8 2000/02/07 10:20:18 ionut Exp $
+ * $Id: mount_linux.c,v 1.11.2.1 2000/08/25 00:56:34 ezk Exp $
  */
 
 /*
@@ -154,12 +154,12 @@ parse_opts(char *type, char *optstr, int *flags, char **xopts, int *noauto)
        * and parse the fs-specific options
        */
 #ifdef MOUNT_TYPE_PCFS
-      if (!STREQ(type, MOUNT_TYPE_PCFS))
+      if (STREQ(type, MOUNT_TYPE_PCFS))
 	dev_opts = dos_opts;
       else
 #endif /* MOUNT_TYPE_PCFS */
 #ifdef MOUNT_TYPE_CDFS
-	if (!STREQ(type, MOUNT_TYPE_CDFS))
+	if (STREQ(type, MOUNT_TYPE_CDFS))
 	  dev_opts = iso_opts;
 	else
 #endif /* MOUNT_TYPE_CDFS */
@@ -256,12 +256,18 @@ mount_linux(MTYPE_TYPE type, mntent_t *mnt, int flags, caddr_t data)
       mnt_data->rsize = nfs_def_file_io_buffer_size;
     if (!mnt_data->wsize)
       mnt_data->wsize = nfs_def_file_io_buffer_size;
-#if NFS_MOUNT_VERSION >= 4
+    /*
+     * in nfs structure implementation version 4, the old
+     * filehandle field was renamed "old_root" and left as 3rd field,
+     * while a new field called "root" was added to the end of the
+     * structure.
+     */
+#ifdef MNT2_NFS_OPT_VER3
     if (mnt_data->flags & MNT2_NFS_OPT_VER3)
       memset(mnt_data->old_root.data, 0, FHSIZE);
     else
+#endif /* MNT2_NFS_OPT_VER3 */
       memcpy(mnt_data->old_root.data, mnt_data->root.data, FHSIZE);
-#endif /* NFS_MOUNT_VERSION >=4 */
 
 #ifdef HAVE_FIELD_NFS_ARGS_T_BSIZE
     /* linux mount version 3 */
@@ -347,9 +353,11 @@ mount_linux(MTYPE_TYPE type, mntent_t *mnt, int flags, caddr_t data)
     plog(XLOG_DEBUG, "linux mount: dir %s\n", mnt->mnt_dir);
   }
   amuDebug(D_TRACE) {
-    plog(XLOG_DEBUG, "linux mount: updated nfs_args...");
     plog(XLOG_DEBUG, "linux mount: Generic mount flags 0x%x", MS_MGC_VAL | flags);
-    print_nfs_args(mnt_data, 0);
+    if (STREQ(type, MOUNT_TYPE_NFS)) {
+      plog(XLOG_DEBUG, "linux mount: updated nfs_args...");
+      print_nfs_args(mnt_data, 0);
+    }
   }
 #endif /* DEBUG */
 
