@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: am_defs.h,v 1.15 2000/02/07 10:20:18 ionut Exp $
+ * $Id: am_defs.h,v 1.15.2.3 2000/05/26 23:40:50 ionut Exp $
  *
  */
 
@@ -331,14 +331,15 @@ extern int errno;
 /* ensure that struct datum is not included again from <rpcsvc/yp_prot.h> */
 #  define DATUM
 # endif /* not DATUM */
-#endif /* HAVE_NDBM_H */
-#ifdef HAVE_DB1_NDBM_H
-# include <db1/ndbm.h>
-# ifndef DATUM
+#else /* not HAVE_NDBM_H */
+# ifdef HAVE_DB1_NDBM_H
+#  include <db1/ndbm.h>
+#  ifndef DATUM
 /* ensure that struct datum is not included again from <rpcsvc/yp_prot.h> */
-#  define DATUM
-# endif /* not DATUM */
-#endif /* HAVE_DB1_NDBM_H */
+#   define DATUM
+#  endif /* not DATUM */
+# endif /* HAVE_DB1_NDBM_H */
+#endif /* HAVE_NDBM_H */
 
 /*
  * Actions to take if <net/errno.h> exists.
@@ -559,6 +560,19 @@ struct ypall_callback;
 /* conflicts with <statfsbuf.h> */
 #  define _SYS_STATFS_H
 # endif /* _SYS_MOUNT_H */
+# ifndef _LINUX_STRING_H_
+#  define _LINUX_STRING_H_
+# endif /* not _LINUX_STRING_H_ */
+# ifdef HAVE_LINUX_KDEV_T_H
+#  define __KERNEL__
+#  include <linux/kdev_t.h>
+#  undef __KERNEL__
+# endif /* HAVE_LINUX_KDEV_T_H */
+# ifdef HAVE_LINUX_LIST_H
+#  define __KERNEL__
+#  include <linux/list.h>
+#  undef __KERNEL__
+# endif /* HAVE_LINUX_LIST_H */
 # include <linux/fs.h>
 #endif /* HAVE_LINUX_FS_H */
 
@@ -651,6 +665,7 @@ struct ypall_callback;
 # define _LINUX_NFS_H
 # define _LINUX_NFS2_H
 # define _LINUX_NFS_FS_H
+# define _LINUX_IN_H
 # include <linux/nfs_mount.h>
 #endif /* HAVE_LINUX_NFS_MOUNT_H */
 
