@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1999 Erez Zadok
+ * Copyright (c) 1997-2000 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: xdr_func.c,v 1.1.1.1 1998/11/05 02:04:45 ezk Exp $
+ * $Id: xdr_func.c,v 1.4 2000/02/11 02:09:54 ezk Exp $
  *
  */
 
@@ -77,7 +77,7 @@ bool_t
 xdr_attrstat(XDR *xdrs, nfsattrstat *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_attrstat:");
 #endif /* DEBUG */
 
@@ -103,7 +103,7 @@ bool_t
 xdr_createargs(XDR *xdrs, nfscreateargs *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_createargs:");
 #endif /* DEBUG */
 
@@ -123,7 +123,7 @@ bool_t
 xdr_dirlist(XDR *xdrs, nfsdirlist *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_dirlist:");
 #endif /* DEBUG */
 
@@ -143,7 +143,7 @@ bool_t
 xdr_diropargs(XDR *xdrs, nfsdiropargs *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_diropargs:");
 #endif /* DEBUG */
 
@@ -163,7 +163,7 @@ bool_t
 xdr_diropokres(XDR *xdrs, nfsdiropokres *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_diropokres:");
 #endif /* DEBUG */
 
@@ -183,7 +183,7 @@ bool_t
 xdr_diropres(XDR *xdrs, nfsdiropres *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_diropres:");
 #endif /* DEBUG */
 
@@ -209,7 +209,7 @@ bool_t
 xdr_dirpath(XDR *xdrs, dirpath *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_dirpath:");
 #endif /* DEBUG */
 
@@ -226,7 +226,7 @@ bool_t
 xdr_entry(XDR *xdrs, nfsentry *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_entry:");
 #endif /* DEBUG */
 
@@ -252,7 +252,7 @@ bool_t
 xdr_exportnode(XDR *xdrs, exportnode *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_exportnode:");
 #endif /* DEBUG */
 
@@ -279,7 +279,7 @@ bool_t
 xdr_exports(XDR *xdrs, exports *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_exports:");
 #endif /* DEBUG */
 
@@ -296,7 +296,7 @@ bool_t
 xdr_fattr(XDR *xdrs, nfsfattr *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_fattr:");
 #endif /* DEBUG */
 
@@ -352,7 +352,7 @@ bool_t
 xdr_fhandle(XDR *xdrs, fhandle objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_fhandle:");
 #endif /* DEBUG */
 
@@ -369,7 +369,7 @@ bool_t
 xdr_fhstatus(XDR *xdrs, fhstatus *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_fhstatus:");
 #endif /* DEBUG */
 
@@ -389,7 +389,7 @@ bool_t
 xdr_filename(XDR *xdrs, filename *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_filename:");
 #endif /* DEBUG */
 
@@ -406,7 +406,7 @@ bool_t
 xdr_ftype(XDR *xdrs, nfsftype *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_ftype:");
 #endif /* DEBUG */
 
@@ -423,7 +423,7 @@ bool_t
 xdr_groupnode(XDR *xdrs, groupnode *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_groupnode:");
 #endif /* DEBUG */
 
@@ -447,7 +447,7 @@ bool_t
 xdr_groups(XDR *xdrs, groups objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_groups:");
 #endif /* DEBUG */
 
@@ -464,7 +464,7 @@ bool_t
 xdr_linkargs(XDR *xdrs, nfslinkargs *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_linkargs:");
 #endif /* DEBUG */
 
@@ -484,7 +484,7 @@ bool_t
 xdr_mountbody(XDR *xdrs, mountbody *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_mountbody:");
 #endif /* DEBUG */
 
@@ -507,7 +507,7 @@ bool_t
 xdr_mountlist(XDR *xdrs, mountlist *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_mountlist:");
 #endif /* DEBUG */
 
@@ -531,7 +531,7 @@ bool_t
 xdr_fhandle3(XDR *xdrs, fhandle3 *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_fhandle3:");
 #endif /* DEBUG */
 
@@ -548,7 +548,7 @@ bool_t
 xdr_mountstat3(XDR *xdrs, mountstat3 *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_mountstat3:");
 #endif /* DEBUG */
 
@@ -562,7 +562,7 @@ bool_t
 xdr_mountres3_ok(XDR *xdrs, mountres3_ok *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_mountres3_ok:");
 #endif /* DEBUG */
 
@@ -583,7 +583,7 @@ bool_t
 xdr_mountres3(XDR *xdrs, mountres3 *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_mountres3:");
 #endif /* DEBUG */
 
@@ -604,7 +604,7 @@ bool_t
 xdr_name(XDR *xdrs, name *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_name:");
 #endif /* DEBUG */
 
@@ -621,7 +621,7 @@ bool_t
 xdr_nfs_fh(XDR *xdrs, am_nfs_fh *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_nfs_fh:");
 #endif /* DEBUG */
 
@@ -638,7 +638,7 @@ bool_t
 xdr_nfscookie(XDR *xdrs, nfscookie objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_nfscookie:");
 #endif /* DEBUG */
 
@@ -655,7 +655,7 @@ bool_t
 xdr_nfspath(XDR *xdrs, nfspath *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_nfspath:");
 #endif /* DEBUG */
 
@@ -672,7 +672,7 @@ bool_t
 xdr_nfsstat(XDR *xdrs, nfsstat *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_nfsstat:");
 #endif /* DEBUG */
 
@@ -689,7 +689,7 @@ bool_t
 xdr_nfstime(XDR *xdrs, nfstime *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_nfstime:");
 #endif /* DEBUG */
 
@@ -709,7 +709,7 @@ bool_t
 xdr_pointer(register XDR *xdrs, char **objpp, u_int obj_size, XDRPROC_T_TYPE xdr_obj)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_pointer:");
 #endif /* DEBUG */
 
@@ -735,7 +735,7 @@ bool_t
 xdr_readargs(XDR *xdrs, nfsreadargs *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_readargs:");
 #endif /* DEBUG */
 
@@ -761,7 +761,7 @@ bool_t
 xdr_readdirargs(XDR *xdrs, nfsreaddirargs *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_readdirargs:");
 #endif /* DEBUG */
 
@@ -784,7 +784,7 @@ bool_t
 xdr_readdirres(XDR *xdrs, nfsreaddirres *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_readdirres:");
 #endif /* DEBUG */
 
@@ -810,7 +810,7 @@ bool_t
 xdr_readlinkres(XDR *xdrs, nfsreadlinkres *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_readlinkres:");
 #endif /* DEBUG */
 
@@ -836,7 +836,7 @@ bool_t
 xdr_readokres(XDR *xdrs, nfsreadokres *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_readokres:");
 #endif /* DEBUG */
 
@@ -859,7 +859,7 @@ bool_t
 xdr_readres(XDR *xdrs, nfsreadres *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_readres:");
 #endif /* DEBUG */
 
@@ -885,7 +885,7 @@ bool_t
 xdr_renameargs(XDR *xdrs, nfsrenameargs *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_renameargs:");
 #endif /* DEBUG */
 
@@ -905,7 +905,7 @@ bool_t
 xdr_sattr(XDR *xdrs, nfssattr *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_sattr:");
 #endif /* DEBUG */
 
@@ -937,7 +937,7 @@ bool_t
 xdr_sattrargs(XDR *xdrs, nfssattrargs *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_sattrargs:");
 #endif /* DEBUG */
 
@@ -957,7 +957,7 @@ bool_t
 xdr_statfsokres(XDR *xdrs, nfsstatfsokres *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_statfsokres:");
 #endif /* DEBUG */
 
@@ -986,7 +986,7 @@ bool_t
 xdr_statfsres(XDR *xdrs, nfsstatfsres *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_statfsres:");
 #endif /* DEBUG */
 
@@ -1012,7 +1012,7 @@ bool_t
 xdr_symlinkargs(XDR *xdrs, nfssymlinkargs *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_symlinkargs:");
 #endif /* DEBUG */
 
@@ -1035,7 +1035,7 @@ bool_t
 xdr_writeargs(XDR *xdrs, nfswriteargs *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_writeargs:");
 #endif /* DEBUG */
 
@@ -1071,7 +1071,7 @@ bool_t
 xdr_mntrequest(XDR *xdrs, mntrequest *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_mntrequest:");
 #endif /* DEBUG */
 
@@ -1097,7 +1097,7 @@ bool_t
 xdr_mntres(XDR *xdrs, mntres *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_mntres:");
 #endif /* DEBUG */
 
@@ -1114,7 +1114,7 @@ bool_t
 xdr_umntrequest(XDR *xdrs, umntrequest *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_umntrequest:");
 #endif /* DEBUG */
 
@@ -1142,7 +1142,7 @@ bool_t
 xdr_umntres(XDR *xdrs, umntres *objp)
 {
 #ifdef DEBUG
-  amuDebug(D_TRACE)
+  amuDebug(D_XDRTRACE)
     plog(XLOG_DEBUG, "xdr_mntres:");
 #endif /* DEBUG */
 
